@@ -146,6 +146,7 @@
 /* #undef HAVE_CUSERID */
 #define HAVE_CXX_NEW 1
 /* #undef HAVE_DIRECTIO */
+#define HAVE_DLADDR 1
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
 /* #undef HAVE_DOPRNT */
@@ -414,7 +415,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -490,8 +491,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "alpha"
-#define DEFAULT_MACHINE "alpha"
+#define MACHINE_TYPE "sparc64"
+#define DEFAULT_MACHINE "sparc64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -636,16 +637,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 32
+#define MYSQL_VERSION_PATCH 34
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.32"
+#define PACKAGE_STRING "MySQL Server 10.0.34"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.32"
-#define VERSION "10.0.32"
+#define PACKAGE_VERSION "10.0.34"
+#define VERSION "10.0.34"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
